Packages — bodhi 3.1.0 documentation

# Packages

## Packages service at /packages/

PkgDB packages

### GET

values in the querystring

- like (String) - (optional)
- search (String) - (optional)
- chrome (Boolean) - (default: true)
- page (Integer) - (default: 1)
- rows_per_page (Integer) - (default: 20)
- name (String) - (optional)

Search for packages via query string parameters.

The following query string parameters may be used to limit the packages returned by the service:
  name: The name of the Packages you wish to retrieve. like: Search for Packages with names like the given string. search: Search for Packages with names like the given string, with case insensitivity. page: Retrieve the specified page of search results. rows_per_page: Specify how many rows per page are desired.
Args:
  request (pyramid.request): The current web request.
Returns:
  dict: A dictionary with the following key value mappings:
    packages: An iterable of packages that match the search criteria. page: The current page of results. pages: The number of pages of results. rows_per_page: The number of results per page. total: The total number of packages that match the search criteria.

Validate the location against the schema defined on the service.

The content of the location is deserialized, validated and stored in the `request.validated` attribute.

Note

If no schema is defined, this validator does nothing.

Param request: | Current request
Type request: | `Request`
Param schema: | The Colander schema
Param deserializer:
| Optional deserializer, defaults to `cornice.validators.extract_cstruct()`

Response: json